* 2016-01-24: tuning travis tox setup\n
* 2016-01-24: more tuning travis setup\n
* 2016-01-24: more tuning travis setup\n
* 2016-01-24: more tuning travis setup\n
* 2016-01-24: more tuning travis setup\n
* 2016-01-24: more tuning travis setup\n
* 2016-01-24: tuning travis setup\n
* 2016-01-24: travis setup\n
* 2016-01-24: initial commit\n